.extend_baseline_matrix: Extend a baseline matrix
Description
This function is called if a scenario is to be created that just
continues with the baseline specification. It is useful to create
a benchmark model to compare new scenarios.
Usage
.extend_baseline_matrix(baseline, periods)
Arguments
- baseline
A baseline model
- periods
The total number of periods to run the model