.make_matrix: Make the underlying matrix that will be modified in place by the solvers
Description
Make the underlying matrix that will be modified in place by the solvers
Usage
.make_matrix(equations, external, periods, initial = NULL)
Arguments
- equations
Prepared equations.
- external
Exogenous and parameters as tibble.
- periods
Total number of rows.
- initial
Initial values, if supplied.