Re-wrote the equations with the correct matrix syntax that will be used to evaluate the expressions inside the Gauss Seidel algorithm
.prep_equations(ordered_eqs, external)ordered equations after passing through .sfcr_find_order() function.
Tibble of exogenous values and parameters, already separated with
.eq_as_tb() function.
João Macalós