Learn R Programming

sfcr (version 0.2.3)

.sfcr_broyden: Broyden solver wrapper

Description

Broyden solver wrapper

Usage

.sfcr_broyden(m, equations, periods, max_ite, tol)

Arguments

m

The initialized matrix obtained with .make_matrix().

equations

Prepared equations with .prep_equations().

periods

Total number of rows (periods) in the model.

max_ite

Maximum number of iterations allowed per block per period.

tol

Tolerance accepted to determine convergence.

Author

João Macalós

Details

This function implements the Broyden method to solve the cyclical blocks of equations.