.sfcr_find_order: Place the equations in the correct order for estimation
Description
Place the equations in the correct order for estimation
Usage
.sfcr_find_order(equations)
Arguments
- equations
Equations supplied by the user.
Details
Create an adjacency matrix and apply
.find_blocks() function to identify the blocks
of independent equations.