Learn R Programming

sfcr (version 0.2.3)

sfcr_dag_blocks: Create a tbl_graph object blocks and cycles information

Description

Create a tbl_graph object blocks and cycles information

Usage

sfcr_dag_blocks(equations)

Value

A tbl_graph

Arguments

equations

A sfcr_set containing all the equations of the model to be simulated. The equations must be written with the R formula syntax, with the left-hand side separated from the right-hand side by a twiddle ~.

Author

João Macalós, joaomacalos@gmail.com

Details

This function creates a tbl_graph with information about the blocks and cycles attached to it. This object can then be used to plot the DAG of the model.