tbl_graph object blocks and cycles informationCreate a tbl_graph object blocks and cycles information
sfcr_dag_blocks(equations)A tbl_graph
A sfcr_set containing all the equations of the model to be simulated. The equations
must be written with the R formula syntax, with the left-hand side separated from the right-hand side
by a twiddle ~.
João Macalós, joaomacalos@gmail.com
This function creates a tbl_graph with information about
the blocks and cycles attached to it. This object can then be used to
plot the DAG of the model.